# Anchorpoint

Anchorpoint supplies TextQuoteSelector and TextPositionSelector classes based on the Web Annotation Data Model, which is a [W3C Recommendation](https://www.w3.org/TR/annotation-model/). Anchorpoint includes helper methods for switching between selector types, and it’s used for referencing judicial opinions and statutes by [AuthoritySpoke](https://authorityspoke.readthedocs.io).

[API Documentation](https://anchorpoint.readthedocs.io) is available on readthedocs.

## Related Packages

In Javascript, try the [Text Quote Anchor](https://www.npmjs.com/package/dom-anchor-text-quote) and [Text Position Anchor](https://www.npmjs.com/package/dom-anchor-text-position) packages.